@@ -1,4 +1,6 @@
+# flake8: noqa:F811
 import dataclasses as dc
+import io
 import tarfile
 import time
 import typing as t
@@ -16,13 +18,19 @@ from requests import HTTPError
 from tabulate import tabulate
 
 from datapane import __rev__, __version__
-from datapane.common import DPError, SDict, _setup_dp_logging, dict_drop_empty, log
-from datapane.common.dp_types import URL, add_help_text
+from datapane import cloud_api as api
+from datapane import legacy_apps as apps
+from datapane.app import hosting_utils
+from datapane.client import log
+from datapane.client.utils import _setup_dp_logging
+from datapane.common import SDict, dict_drop_empty
+from datapane.common.dp_types import URL
+from datapane.legacy_apps import config as sc
 
-from . import analytics, api, apps
+from . import analytics
 from . import config as c
-from .apps import config as sc
-from .utils import failure_msg, process_cmd_param_vals, success_msg
+from .exceptions import DPClientError, add_help_text
+from .utils import process_cmd_param_vals
 
 EXTRA_OUT: bool = False
 
@@ -73,7 +81,7 @@ class GlobalCommandHandler(click.Group):
             analytics.capture("CLI Error", msg=str(e), type=str(type(e)))
             if EXTRA_OUT:
                 log.exception(e)
-            if isinstance(e, DPError):
+            if isinstance(e, DPClientError):
                 failure_msg(str(e))
             else:
                 failure_msg(add_help_text(str(e)), do_exit=True)
@@ -124,6 +132,13 @@ def login(obj: DPContext, token: str, server: str):
     # click.launch(f"{server}/settings/")
 
 
+@cli.command()
+@click.option("--server", default=c.DEFAULT_SERVER, help="Datapane API Server URL.")
+def signup(server: str):
+    """Signup and link your account to the Datapane CLI"""
+    api.signup(server)
+
+
 @cli.command()
 @click.pass_obj
 def logout(obj: DPContext):
@@ -220,7 +235,7 @@ def write_templates(scaffold_name: str, context: SDict):
 
     # copy the scaffolds into the service
     def copy_scaffold() -> List[Path]:
-        dir_path = ir.files("datapane.resources.templates") / scaffold_name
+        dir_path = ir.files("datapane.resources.app_templates") / scaffold_name
         copy_tree(str(dir_path), ".")
         return [Path(x.name) for x in dir_path.iterdir()]
 
@@ -267,7 +282,7 @@ def deploy(
     kwargs = dict_drop_empty(init_kwargs, none_only=True)
 
     # if not (script or config or sc.DatapaneCfg.exists()):
-    #     raise DPError(f"Not valid project dir")
+    #     raise DPClientError(f"Not valid project dir")
 
     dp_cfg = apps.DatapaneCfg.create_initial(**kwargs)
     log.debug(f"Packaging and uploading Datapane project {dp_cfg.name}")
@@ -542,3 +557,103 @@ def delete(id: str):
     """Delete a schedule by its id/url"""
     api.Schedule.by_id(id).delete()
     success_msg(f"Deleted schedule {id}")
+
+
+def success_msg(msg: str):
+    click.secho(msg, fg="green")
+
+
+def failure_msg(msg: str, do_exit: bool = False):
+    click.secho(msg, fg="red")
+    if do_exit:
+        ctx: click.Context = click.get_current_context(silent=True)
+        if ctx:
+            ctx.exit(2)
+        else:
+            exit(2)
+
+
+#############################################################################
+
+# Utilities for helping self-hosting apps
+
+
+@app.group()
+def generate():
+    """Commands to generate misc files"""
+
+
+@generate.command()
+@click.option(
+    "--python",
+    default=hosting_utils.DEFAULT_PYTHON_VERSION,
+    show_default=True,
+)
+@click.option(
+    "--installer",
+    default=hosting_utils.DEFAULT_INSTALLER,
+    show_default=True,
+    type=click.Choice(hosting_utils.SupportedInstallers.as_list(), case_sensitive=False),
+)
+@click.option(
+    "--app-file",
+    prompt="What file contains your App?",
+    default=(lambda: next(hosting_utils.python_files(), None)),
+    type=click.Path(exists=False, dir_okay=False),
+    help="The App file you'd like to run (contains dp.serve_app(...))",
+)
+@click.option(
+    "--output", "-o", default="Dockerfile", show_default=True, type=click.File(mode="w", lazy=True, atomic=True)
+)
+def dockerfile(python: str, installer: str, app_file: t.Union[str, Path, None], output: io.TextIOWrapper):
+    """Generate a dockerfile to help with hosting Apps"""
+    _installer = hosting_utils.SupportedInstallers[installer]
+
+    if Path(output.name).exists() and output.name != "-":
+        click.confirm(f"output file '{output.name}' exists. Overwrite?", default=False, abort=True)
+
+    contents = hosting_utils.generate_dockerfile(python_version=python, installer=_installer, app_file=app_file)
+    output.write(contents)
+
+
+@generate.command()
+@click.option(
+    "--nb",
+    "--app-file",
+    "nb_path",
+    prompt="What notebook would you like to convert?",
+    default=(lambda: next(hosting_utils.python_files(extensions=[".ipynb"]), None)),
+    type=click.Path(exists=True, readable=True, dir_okay=False, resolve_path=True),
+)
+@click.option(
+    "-o",
+    "--out",
+    "output",
+    type=click.File(mode="w", lazy=True, atomic=True),
+)
+def script_from_nb(nb_path: t.Union[str, Path], output: t.Union[t.IO, None]):
+    """Generate a script from a Jupyter Notebook
+
+    Uses nbconvert to extract as a python script, with modifications
+    to provide a more seamless experience.
+
+    Outputs are not preserved.
+    """
+    from datapane.ipython.utils import extract_py_notebook
+
+    nb_path = Path(nb_path)
+    cwd = Path.cwd()
+    if output is None:
+        output_path = cwd / nb_path.with_suffix(".py").name
+        output = click.open_file(str(output_path), mode="w", atomic=True)
+
+    with click.open_file(str(nb_path), mode="r") as nb_file:
+        py_contents = extract_py_notebook(nb_file)
+
+    if output.name != "-":
+        click.echo(f"Writing to file: {click.format_filename(output.name, shorten=True)}")
+        if Path(output.name).exists():
+            click.confirm("File exists. Overwrite?", default=False, abort=True)
+
+    with output as f:
+        f.write(py_contents)
