@@ -7,18 +7,16 @@ import configparser
 import dataclasses as dc
 import typing as t
 import uuid
-import webbrowser
 from contextlib import suppress
 from os import getenv
 from pathlib import Path
 from typing import Optional
 
 import click
-from furl import furl
+from typing_extensions import Self
 
-from datapane import _IN_PYTEST, log
-
-from .utils import InvalidTokenError
+from .exceptions import InvalidTokenError
+from .utils import IN_PYTEST, log
 
 APP_NAME = "datapane"
 APP_DIR = Path(getenv("DATAPANE_APP_DIR", click.get_app_dir(APP_NAME)))
@@ -79,7 +77,7 @@ class Config:
 
     # MANAGER functions
     @classmethod
-    def load(cls) -> "Config":
+    def load(cls) -> Self:
         """Load config for an environment and set globally"""
         # Read config file
         cls.ensure_config_file()
@@ -163,18 +161,18 @@ class Config:
         if self.version in (1, 2, 3):
             # If token exists check still valid and can login, use to get server props
             if self.token and self.token != DEFAULT_TOKEN:
-                from .api.user import ping
+                from ..cloud_api.user import ping
 
                 with suppress(Exception):
                     # get the email for v4 of spec
                     self.email = ping(config=self, cli_login=True, verbose=False)
 
-                if not self.completed_action:
-                    # we could be on older version, but with a valid token
-                    # but haven't completed an action, so force it
-                    from .analytics import capture
-
-                    capture("CLI Login", config=self, with_token=True)
+                # if not self.completed_action:
+                #     # we could be on older version, but with a valid token
+                #     # but haven't completed an action, so force it
+                #     from .analytics import capture
+                #
+                #     capture("CLI Login", config=self, with_token=True)
 
             self.version = LATEST_VERSION
             self.save()
@@ -213,13 +211,17 @@ def check_get_config() -> Config:
         # try reinit, as may have ran login in another terminal/subprocess
         _config = init()
         if _config.token == DEFAULT_TOKEN:
-            # still don't have a token set, open up the browser
-            if not _IN_PYTEST:
-                f = furl(path="/accounts/login/", origin=_config.server)
-                webbrowser.open(url=str(f), new=2)
+            # still don't have a token set, open up the browser and wait for login
+            if not IN_PYTEST:
+                from datapane.cloud_api import signup
+
+                signup()
+                _config = init()
+                return _config
             raise InvalidTokenError(
                 "Please sign-up and login - if you already have then please restart your Jupyter kernel/Python instance to initialize your new token"
             )
+
         return _config
     return config
 
